'From etoys4.0 of 9 October 2008 [latest update: #2237] on 4 August 2009 at 12:33:11 am'!

!Morph methodsFor: 'halos and balloon help' stamp: 'KR 7/31/2009 01:07'!
balloonHelpTextForHandle: aHandle
	"Answer a string providing balloon help for the given halo handle"

	|  itsSelector |
	itsSelector _ aHandle eventHandler firstMouseSelector.
	(#(	(addFullHandles							'More halo handles'	)
		(addSimpleHandles						'Fewer halo handles'	)
		(chooseEmphasisOrAlignment				'Emphasis & alignment'	)
		(chooseFont								'Change font'			)
		(chooseNewGraphicFromHalo				'Choose a new graphic'	)
		(chooseStyle								'Change style'		)
		(dismiss									'Remove'				)
		(doDebug:with:							'Debug (press shift to inspect morph)'	)
		(doDirection:with:						'Choose forward direction'	)
		(doDup:with:							'Duplicate'				)
		(doDupOrMakeSibling:with: 				'Duplicate (press shift to make a sibling)'	)
		(doMakeSiblingOrDup:with: 				'Make a sibling (press shift to make simple duplicate)'		)
		(doMakeSibling:with: 					'Make a sibling'		)
		(doMenu:with:							'Menu'			)
		(doGrab:with:							'Pick up'				)
		(editButtonsScript						'See the script for this button'	)
		(editDrawing							'Repaint'				)
		(maybeDoDup:with:						'Duplicate'		)
		(makeNascentScript						'Make a scratch script'	)
		(makeNewDrawingWithin				'Paint new object'		)
		(mouseDownInCollapseHandle:with:		'Collapse'	)
		(mouseDownOnHelpHandle:				'Help'	)
		(openViewerForArgument				'Open a Viewer for me'	)
		(openViewerForTarget:with:				'Open a Viewer for me')
		(paintBackground						'Paint background'	)
		(prepareToTrackCenterOfRotation:with:	'Center of rotation (hold down shift key and drag to change it)'	)
		(presentViewMenu						'Present the Viewing menu'	)
		(startDrag:with:							'Move'					)
		(startGrow:with:							'Change size (press shift to preserve aspect)'	) 
		(startRot:with:							'Rotate'	)
		(startScale:with:							'Change scale'	) 
		(tearOffTile								'Make a tile representing this object'	)
		(tearOffTileForTarget:with:				'Make a tile representing this object')
		(trackCenterOfRotation:with:				'Set center of rotation'	))  translatedNoopWithContext: 'EtoysHelpString')
	do:
		[:pair | itsSelector == pair first ifTrue: [^ pair second]].

	(itsSelector == #mouseDownInDimissHandle:with:) ifTrue:
		[^ Preferences preserveTrash
			ifTrue:
				['Move to trash' translatedNoopWithContext: 'EtoysHelpString']
			ifFalse:
				['Remove from screen' translatedNoopWithContext: 'EtoysHelpString']].

	(itsSelector == #doRecolor:with:) ifTrue: [
		^ Preferences propertySheetFromHalo
			ifTrue: ['Property Sheet (press shift for simple recolor)' translatedNoopWithContext: 'EtoysHelpString']
			ifFalse: ['Change color (press shift for more properties)' translatedNoopWithContext: 'EtoysHelpString']].

	^ 'unknown halo handle'! !


!HaloMorph methodsFor: 'private' stamp: 'KR 7/31/2009 01:14'!
addGraphicalHandle: formKey at: aPoint on: eventName send: selector to: recipient
	"Add the supplied form as a graphical handle centered at the given point, and set it up to respond to the given event by sending the given selector to the given recipient.  Return the handle."
	| handle |
	handle _ self addGraphicalHandleFrom: formKey at: aPoint.
	handle on: eventName send: selector to: recipient.
	handle setBalloonText: ((target balloonHelpTextForHandle: handle) translatedWithContext: 'EtoysHelpString').
	^ handle
! !

!HaloMorph methodsFor: 'private' stamp: 'KR 7/31/2009 01:13'!
addHandle: handleSpec on: eventName send: selector to: recipient
	"Add a handle within the halo box as per the haloSpec, and set it up to respond to the given event by sending the given selector to the given recipient.  Return the handle."

	| handle aPoint form |
	Preferences biggerHandles ifFalse: [^ self addSmallHandle: handleSpec on: eventName send: selector to: recipient].
	aPoint _ self positionIn: haloBox horizontalPlacement: handleSpec horizontalPlacement verticalPlacement: handleSpec verticalPlacement.

	handle := ThreePhaseButtonMorph labelSymbol: handleSpec iconSymbol.
	handle center: aPoint.
	self addMorph: handle.
	handle on: #mouseUp send: #endInteraction to: self.
	handle on: eventName send: selector to: recipient.
	self isMagicHalo ifTrue:[
		handle on: #mouseEnter send: #handleEntered to: self.
		handle on: #mouseLeave send: #handleLeft to: self].
	handle setBalloonText: ((target balloonHelpTextForHandle: handle) translatedWithContext: 'EtoysHelpString').
	^ handle
! !

!HaloMorph methodsFor: 'private' stamp: 'KR 7/31/2009 01:14'!
addHandleAt: aPoint color: aColor icon: iconName on: eventName send: selector to: recipient
	"Add a handle centered at the given point with the given color, and set it up to respond to the given event by sending the given selector to the given recipient.  Return the handle."
	| handle |
	handle _ EllipseMorph
		newBounds: (Rectangle center: aPoint extent: self handleSize asPoint)
		color: aColor.
	handle borderColor: aColor muchDarker.
	self addMorph: handle.
	iconName ifNotNil:
		[ | form |
		form _ ScriptingSystem formAtKey: iconName.
		form ifNotNil:
			[handle addMorphCentered: (ImageMorph new
				image: form; 
				color: aColor makeForegroundColor;
				lock)]].
	handle on: #mouseUp send: #endInteraction to: self.
	handle on: eventName send: selector to: recipient.
	handle setBalloonText: ((target balloonHelpTextForHandle: handle) translatedWithContext: 'EtoysHelpString').
	^ handle
! !

!HaloMorph methodsFor: 'private' stamp: 'KR 7/31/2009 01:13'!
addSmallHandle: handleSpec on: eventName send: selector to: recipient
	"Add a handle within the halo box as per the haloSpec, and set it up to respond to the given event by sending the given selector to the given recipient.  Return the handle.  This is the 5/17/04 version of HaloMorph>>addHandle:on:send:to:"

	| handle aPoint iconName colorToUse |
	aPoint _ self positionIn: haloBox horizontalPlacement: handleSpec horizontalPlacement verticalPlacement: handleSpec verticalPlacement.
	handle _ EllipseMorph
		newBounds: (Rectangle center: aPoint extent: self handleSize asPoint)
		color: (colorToUse _ Color colorFrom: handleSpec color).
	handle borderColor: colorToUse muchDarker.
	self addMorph: handle.
	(iconName _ handleSpec iconSymbol) ifNotNil:
		[ | form |
		form _ ScriptingSystem formAtKey: iconName.
		form ifNotNil:
			[handle addMorphCentered: (ImageMorph new
				image: form; 
				color: colorToUse makeForegroundColor;
				lock)]].
	handle on: #mouseUp send: #endInteraction to: self.
	handle on: eventName send: selector to: recipient.
	self isMagicHalo ifTrue:[
		handle on: #mouseEnter send: #handleEntered to: self.
		handle on: #mouseLeave send: #handleLeft to: self].
	handle setBalloonText: ((target balloonHelpTextForHandle: handle) translatedWithContext: 'EtoysHelpString').
	^ handle
! !

